@@ -2,16 +2,17 @@ from fabric.api import env
 from fabric.contrib import django
 
 import deploy
-import merge
 import pull_request
 import refresh
+import stage
 import sync
 import topic
 
+
 repr(deploy)
-repr(merge)
 repr(pull_request)
 repr(refresh)
+repr(stage)
 repr(sync)
 repr(topic)
 
@@ -25,4 +26,7 @@ for required_setting in required_settings:
   if not hasattr(env, required_setting):
     raise RuntimeError('You must set %s in fabfile.py' % required_setting)
 
+env.production_branch = getattr(env, 'production_branch', 'master')
+env.staging_branch = getattr(env, 'staging_branch', 'staging')
+
 django.settings_module(env.django_settings_module)
